@@ -26,10 +26,7 @@
 
 #include "akonadi-mime_export.h"
 
-
-namespace Akonadi
-{
-
+namespace Akonadi {
 /**
  * @short Job that finds and removes duplicate messages in given collection
  *
@@ -71,11 +68,7 @@ protected:
 private:
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void slotFetchDone(KJob *job))
-    Q_PRIVATE_SLOT(d, void slotDeleteDone(KJob *job))
 };
-
 } /* namespace Akonadi */
 
 #endif // REMOVEDUPLICATESJOB_H
